package com.ruoyi.system.service.impl.projectV2.common;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.projectV2.common.SendSmsConfig;
import com.ruoyi.system.mapper.projectV2.common.SendSmsConfigMapper;
import com.ruoyi.system.service.projectV2.common.ISendSmsConfigService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 短信人员配置Service业务层处理
 * 
 * @author boman
 * @date 2023-03-07
 */
@Service
public class SendSmsConfigServiceImpl implements ISendSmsConfigService
{
    @Autowired
    private SendSmsConfigMapper sendSmsConfigMapper;

    /**
     * 查询短信人员配置
     * 
     * @param id 短信人员配置主键
     * @return 短信人员配置
     */
    @Override
    public SendSmsConfig selectSendSmsConfigById(Long id)
    {
        return sendSmsConfigMapper.selectSendSmsConfigById(id);
    }

    /**
     * 查询短信人员配置列表
     * 
     * @param sendSmsConfig 短信人员配置
     * @return 短信人员配置
     */
    @Override
    public List<SendSmsConfig> selectSendSmsConfigList(SendSmsConfig sendSmsConfig)
    {
        return sendSmsConfigMapper.selectSendSmsConfigList(sendSmsConfig);
    }

    /**
     * 新增短信人员配置
     * 
     * @param sendSmsConfig 短信人员配置
     * @return 结果
     */
    @Override
    public int insertSendSmsConfig(SendSmsConfig sendSmsConfig)
    {
        sendSmsConfig.setCreateTime(DateUtils.getNowDate());
        return sendSmsConfigMapper.insertSendSmsConfig(sendSmsConfig);
    }

    /**
     * 修改短信人员配置
     * 
     * @param sendSmsConfig 短信人员配置
     * @return 结果
     */
    @Override
    public int updateSendSmsConfig(SendSmsConfig sendSmsConfig)
    {
        sendSmsConfig.setUpdateTime(DateUtils.getNowDate());
        return sendSmsConfigMapper.updateSendSmsConfig(sendSmsConfig);
    }

    /**
     * 批量删除短信人员配置
     * 
     * @param ids 需要删除的短信人员配置主键
     * @return 结果
     */
    @Override
    public int deleteSendSmsConfigByIds(Long[] ids)
    {
        return sendSmsConfigMapper.deleteSendSmsConfigByIds(ids);
    }

    /**
     * 删除短信人员配置信息
     * 
     * @param id 短信人员配置主键
     * @return 结果
     */
    @Override
    public int deleteSendSmsConfigById(Long id)
    {
        return sendSmsConfigMapper.deleteSendSmsConfigById(id);
    }
}
